.. Copyright 2013-2023 Reahl Software Services (Pty) Ltd. All rights reserved.


XML reference for .reahlproject
===============================

Since version 7.0.0 Reahl projects are fully configured using a standard PEP621 `pyproject.toml` file.

See doc::`<component/pyproject.toml.rst>`.

